<?xml version="1.0" ?><!DOCTYPE TS><TS language="he_IL" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>נכשל בפתיחת מסד הנתונים של חשבונות</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>click to open the website</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>pro version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Account settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add an account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>not logged in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>server</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>משימות להורדה</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>להסיר את כל המשימות המוצלחות</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>אין משימות להורדה עכשיו.</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>לפנות</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>לסגור</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>ספרייה</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>נתיב</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>בטל משימה זו</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>בטל משימה זו</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>הסר משימה זו</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>נכשל ניסיון ביטול משימה זו:

%1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>נכשל ניסיון להסיר משימה זו:

%1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>לצמצם</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>סגור</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Starred</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Activities</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>current download rate</source>
        <translation>קצב הורדה הנוכחי</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>קצב העלאה הנוכחי</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>אנא בחר תיקייה לסנכרן</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>שום שרת מחובר</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>כל השרתים מחוברים</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>חלק מהשרתים אינם מחוברים</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>טופס</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>לוגו</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>לצמצם</translation>
    </message>
    <message>
        <source>close</source>
        <translation>סגור</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>בחר</translation>
    </message>
    <message>
        <source>brand</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>או שחרר תיקייה כדי לסנכרן</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>קצב הורדה</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>חץ למטה</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>קצב העלאה</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>חץ למעלה</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>שגיאה בעת יצירת תצורת ccnet</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>נכשל בקריאה 1%</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>ליצור ספרייה</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>אנא בחר ספרייה</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>יוצר...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>נא לבחור את הספרייה כדי לסנכרן</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>התיקייה %1 אינה קיימת</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>אנא הכנס את השם</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>אנא הכנס את הסיסמה</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>סיסמאות אינן תואמות</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>שגיאה לא ידועה</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>נכשל ניסיון להוסיף משימה להורדה:
%1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>נתיב:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>בחר</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>מוצפן</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>סיסמא:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>סיסמא שוב:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation> תיאור מצב</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>%1 client failed to initialize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 exited unexpectedly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>אנא הכנס את הסיסמה</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>סנכרון ספריית &quot;1%&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>נכשל ניסיון להוסיף משימה להורדה:
%1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Library</source>
        <translation>הורד ספרייה</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>בחר...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>סיסמא לספרייה זו:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Modified files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Added folders</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create a folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get link</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File save failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>pending</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Modifier</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FinderSyncHost</name>
    <message>
        <source>Failed to get link</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>אתחול %1</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>אנא בחר ספרייה</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>אתחול לא הושלם. לפרוש בכל מקרה?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>התיקייה %1 אינה קיימת</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>לוגו</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose...</source>
        <translation>בחר...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>הבא</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>בדיקת ספריית ברירת המחדל שלך...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>יצירת ספריית ברירת מחדל...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>נכשל ביצירת ספריית ברירת מחדל:

גרסת השרת חייבת להיות 2.1 או גבוה כדי לתמוך בזה.</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>מוריד ספריית ברירת מחדל...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>ספריית ברירת המחדל הורד.
אתה יכול ללחוץ על הכפתור &quot;פתח&quot; כדי לצפות בו.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>שגיאה בעת הורדת ספריית ברירת המחדל: %1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>נכשל בניסיון להוריד ספריית ברירת מחדל:
 %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>דלג</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>הפעל ברקע</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>פתח</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>סיים</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>הורד את ספריית ברירת המחדל</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>כן</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>לוגו</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogDirUploader</name>
    <message>
        <source>Upload log files failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files failed :%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Successfully uploaded log files</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogUploadProgressDialog</name>
    <message>
        <source>Compressing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>הוסף חשבון</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>התחברות</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>שגיאת רשת:
 %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;אזהרה:&lt;/ b&gt; תעודת SSL של שרת זה אינה מהימנה, להמשיך בכל זאת?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>אנא הכנס את כתובת השרת</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 אינו כתובת שרת חוקית</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>אנא הכנס את שם המשתמש</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>נכשל בשמירת החשבון הנוכחי</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>אנא הכנס את הסיסמה</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>דוא&quot;ל או סיסמא שגוי</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>שגיאה פנימית בשרת</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>נכשל בהתחברות: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>נכשל בהתחברות</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>לוגו</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password:</source>
        <translation>סיסמא:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation> תיאור מצב</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Login</source>
        <translation>התחבר</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add an account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>רענן</translation>
    </message>
</context>
<context>
    <name>MessagePoller</name>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by another user. Update to this file is not uploaded.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file %1 is denied by folder permission setting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share To:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>מסונכרן</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>יצירת אינדקס של הקבצים</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>אתחול הסינכרון</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>הורדה</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>מעלאה</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>מיזוג סנכרון</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>מחכה לסנכרון</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>שרת אינו מחובר</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>מאמת שרת</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>סינכרון אוטומטי כבוי</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>לא ידועה</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>שרת הוסר</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>אתה לא התחברת לשרת</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>אין לך הרשאה לגשת לספרייה זו</translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>שטח האחסון של בעל הספרייה כבר התמלא</translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>שירות מרחוק אינו זמין</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>הספרייה נמחקה בשרת</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>initializing...</source>
        <translation>אתחול...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>מתחבר השרת...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>יצירת אינדקס של הקבצים</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>יצירת תיקייה...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>למזג את השינויים בקובץ...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>נשלם</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>מבטל</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>בוטל</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>copy failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Added</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Renamed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Added or modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Added directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>directories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>and %1 more</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 day ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PDF Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audio File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Word Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Excel Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file denied by folder permission setting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Client is already running</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error occurred in upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error occurred in download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission denied on server. Please try to resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try to resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not have write permission to the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not have permission to sync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No permission to sync this folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>ספרייה &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>ספרייה זו עדיין לא הורדה</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>שגיאה:</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>סמל מאגר</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>שם מאגר</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>תיאור:</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>תוויתטקסט</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>בעל:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>שונה לאחרונה:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>mtime</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>נתיב מקומי:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>מצב:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation> מצב המאגר</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>לסגור</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>, %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>ספרייה זו לא בוצעה הורדה</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>עודכן לאחרונה</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>הספריות שלי</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>תת ספריות</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sync initializing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>להשבית סנכרון אוטומטי</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>אפשר סנכרון האוטומטי</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>לסנכרן את הספרייה זו באופן מיידי</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>ביטול הורדה</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>ביטול הורדה של ספרייה זו</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>&amp;פתח את תיקייה</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>לפתוח את התיקייה מקומית</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>ביטול &amp;סינכרון</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>נתק מסינכרן ספרייה זו</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>&amp;הצג בא ענן</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>להציג ספרייה זו ב-seahub</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>נתק מסינכרן ספרייה זו</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>נכשל ניסיון ביטול משימה זו:

%1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>ההורדה בוטלה</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to save client id</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to access %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>incorrect client id</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Internal Link:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>Unknown error</source>
        <translation>שגיאה לא ידועה</translation>
    </message>
    <message>
        <source>internal error: failed to connect to daemon</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>להשבית סנכרון אוטומטי</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>אפשר סנכרון האוטומטי</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>צא</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>הצג חלון ראשי</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>הצג תיבת אודות של היישום</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>עזרה &amp;באינטרנט</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>סנכרון אוטומטי הינו מושבת</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>חלק מהשרתים אינם מחוברים</translation>
    </message>
    <message>
        <source>Upload log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>upload %1 log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please login first</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>מצב חיבור שרתים</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>מחובר</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>מנותק</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>לסגור</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>הסתר חלון ראשי בתחילה</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>הצג הודעה כאשר ספריות מסונכרנות</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>מגבלת מהירות ההורדה (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>מגבלת מהירות ההעלאה (KB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove Share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Direct Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open this file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>view this file on website</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TwoFactorDialog</name>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>mText</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember this device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>הסרת התקנה של 1%</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>האם אתה רוצה להסיר את פרטי חשבון של 1%?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>הסרת פרטי חשבון...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>text</source>
        <translation>טקסט</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>כן</translation>
    </message>
    <message>
        <source>No</source>
        <translation>לא</translation>
    </message>
</context>
</TS>